# Third-party Specifications

This directory is not intended to contain durable copies of third-party specifications.
Rather, we fetch and preprocess those specifications so that we are reasoning about the latest version.
These specifications are used when generating/reviewing [design documentation](../dev/) and the codebase.
